summaryrefslogtreecommitdiffstats
path: root/contrib/python/boto3
diff options
context:
space:
mode:
authorrobot-piglet <[email protected]>2025-10-25 21:46:13 +0300
committerrobot-piglet <[email protected]>2025-10-25 22:00:30 +0300
commit3bb14fea5dfcf636fb3cf8c17d8192a2ef073194 (patch)
tree586255c028d98e8e884e18b92ac9d74fa31a2a0f /contrib/python/boto3
parent71d288731233ecd8462d241741e46f547742ff2d (diff)
Intermediate changes
commit_hash:768b424c9823fc4861f7ade763e0b049ae9e1929
Diffstat (limited to 'contrib/python/boto3')
-rw-r--r--contrib/python/boto3/py3/.dist-info/METADATA11
-rw-r--r--contrib/python/boto3/py3/README.rst2
-rw-r--r--contrib/python/boto3/py3/boto3/__init__.py2
-rw-r--r--contrib/python/boto3/py3/boto3/docs/resource.py1
-rw-r--r--contrib/python/boto3/py3/boto3/s3/transfer.py8
-rw-r--r--contrib/python/boto3/py3/ya.make2
6 files changed, 12 insertions, 14 deletions
diff --git a/contrib/python/boto3/py3/.dist-info/METADATA b/contrib/python/boto3/py3/.dist-info/METADATA
index 6daed32e2be..e66440533ee 100644
--- a/contrib/python/boto3/py3/.dist-info/METADATA
+++ b/contrib/python/boto3/py3/.dist-info/METADATA
@@ -1,6 +1,6 @@
Metadata-Version: 2.1
Name: boto3
-Version: 1.33.13
+Version: 1.34.89
Summary: The AWS SDK for Python
Home-page: https://github.com/boto/boto3
Author: Amazon Web Services
@@ -15,18 +15,17 @@ Classifier: License :: OSI Approved :: Apache Software License
Classifier: Programming Language :: Python
Classifier: Programming Language :: Python :: 3
Classifier: Programming Language :: Python :: 3 :: Only
-Classifier: Programming Language :: Python :: 3.7
Classifier: Programming Language :: Python :: 3.8
Classifier: Programming Language :: Python :: 3.9
Classifier: Programming Language :: Python :: 3.10
Classifier: Programming Language :: Python :: 3.11
Classifier: Programming Language :: Python :: 3.12
-Requires-Python: >= 3.7
+Requires-Python: >= 3.8
License-File: LICENSE
License-File: NOTICE
-Requires-Dist: botocore (<1.34.0,>=1.33.13)
+Requires-Dist: botocore (<1.35.0,>=1.34.89)
Requires-Dist: jmespath (<2.0.0,>=0.7.1)
-Requires-Dist: s3transfer (<0.9.0,>=0.8.2)
+Requires-Dist: s3transfer (<0.11.0,>=0.10.0)
Provides-Extra: crt
Requires-Dist: botocore[crt] (<2.0a0,>=1.21.0) ; extra == 'crt'
@@ -49,7 +48,7 @@ Boto (pronounced boh-toh) was named after the fresh water dolphin native to the
Notices
-------
-On 2023-12-13, support for Python 3.7 will end for Boto3. This follows the
+On 2023-12-13, support for Python 3.7 ended for Boto3. This follows the
Python Software Foundation `end of support <https://peps.python.org/pep-0537/#lifespan>`__
for the runtime which occurred on 2023-06-27.
For more information, see this `blog post <https://aws.amazon.com/blogs/developer/python-support-policy-updates-for-aws-sdks-and-tools/>`__.
diff --git a/contrib/python/boto3/py3/README.rst b/contrib/python/boto3/py3/README.rst
index 787615a85cc..eb91aca8fc2 100644
--- a/contrib/python/boto3/py3/README.rst
+++ b/contrib/python/boto3/py3/README.rst
@@ -17,7 +17,7 @@ Boto (pronounced boh-toh) was named after the fresh water dolphin native to the
Notices
-------
-On 2023-12-13, support for Python 3.7 will end for Boto3. This follows the
+On 2023-12-13, support for Python 3.7 ended for Boto3. This follows the
Python Software Foundation `end of support <https://peps.python.org/pep-0537/#lifespan>`__
for the runtime which occurred on 2023-06-27.
For more information, see this `blog post <https://aws.amazon.com/blogs/developer/python-support-policy-updates-for-aws-sdks-and-tools/>`__.
diff --git a/contrib/python/boto3/py3/boto3/__init__.py b/contrib/python/boto3/py3/boto3/__init__.py
index 8ce408ac3d0..e7a591bc99f 100644
--- a/contrib/python/boto3/py3/boto3/__init__.py
+++ b/contrib/python/boto3/py3/boto3/__init__.py
@@ -17,7 +17,7 @@ from boto3.compat import _warn_deprecated_python
from boto3.session import Session
__author__ = 'Amazon Web Services'
-__version__ = '1.33.13'
+__version__ = '1.34.89'
# The default Boto3 session; autoloaded when needed.
diff --git a/contrib/python/boto3/py3/boto3/docs/resource.py b/contrib/python/boto3/py3/boto3/docs/resource.py
index d4dff1dbf1b..c222e3ab6ae 100644
--- a/contrib/python/boto3/py3/boto3/docs/resource.py
+++ b/contrib/python/boto3/py3/boto3/docs/resource.py
@@ -255,7 +255,6 @@ class ResourceDocumenter(BaseDocumenter):
intro_link='references_intro',
)
self.member_map['references'] = reference_list
- self._add_overview_of_member_type(section, 'references')
for reference in references:
reference_list.append(reference.name)
# Create a new DocumentStructure for each reference and add contents.
diff --git a/contrib/python/boto3/py3/ya.make b/contrib/python/boto3/py3/ya.make
index 62c9f40eed5..8b34c1a1ddd 100644
--- a/contrib/python/boto3/py3/ya.make
+++ b/contrib/python/boto3/py3/ya.make
@@ -2,7 +2,7 @@
PY3_LIBRARY()
-VERSION(1.33.13)
+VERSION(1.34.89)
LICENSE(Apache-2.0)
diff --git a/contrib/python/boto3/py3/boto3/s3/transfer.py b/contrib/python/boto3/py3/boto3/s3/transfer.py
index 1c8efd4016c..31a2d00c540 100644
--- a/contrib/python/boto3/py3/boto3/s3/transfer.py
+++ b/contrib/python/boto3/py3/boto3/s3/transfer.py
@@ -182,8 +182,8 @@ def create_transfer_manager(client, config, osutil=None):
def _should_use_crt(config):
- # This feature requires awscrt>=0.19.17
- if HAS_CRT and has_minimum_crt_version((0, 19, 17)):
+ # This feature requires awscrt>=0.19.18
+ if HAS_CRT and has_minimum_crt_version((0, 19, 18)):
is_optimized_instance = awscrt.s3.is_optimized_for_system()
else:
is_optimized_instance = False
@@ -256,7 +256,7 @@ class TransferConfig(S3TransferConfig):
:param max_concurrency: The maximum number of threads that will be
making requests to perform a transfer. If ``use_threads`` is
set to ``False``, the value provided is ignored as the transfer
will only ever use the main thread.
:param multipart_chunksize: The partition size of each part for a
multipart transfer.
@@ -281,7 +281,7 @@ class TransferConfig(S3TransferConfig):
:param use_threads: If True, threads will be used when performing
S3 transfers. If False, no threads will be used in
- performing transfers; all logic will be run in the main thread.
+ performing transfers; all logic will be run in the current thread.
:param max_bandwidth: The maximum bandwidth that will be consumed
in uploading and downloading file content. The value is an integer
@@ -256,7 +256,7 @@ class TransferConfig(S3TransferConfig):
making requests to perform a transfer. If ``use_threads`` is
set to ``False``, the value provided is ignored as the transfer
- will only ever use the main thread.
+ will only ever use the current thread.
:param multipart_chunksize: The partition size of each part for a
multipart transfer.